#!/usr/bin/env python3

##
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
# https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import datetime
from typing import Optional


class UTCTzinfo(datetime.tzinfo):
    def utcoffset(self, dt: Optional[datetime.datetime] = None) -> datetime.timedelta:
        return datetime.timedelta(0)

    def tzname(self, dt: Optional[datetime.datetime] = None) -> str:
        return "UTC"

    def dst(self, dt: Optional[datetime.datetime] = None) -> datetime.timedelta:
        return datetime.timedelta(0)


utc = UTCTzinfo()


# Test Time Zone with fixed offset and no DST
class TSTTzinfo(datetime.tzinfo):
    def utcoffset(self, dt: Optional[datetime.datetime] = None) -> datetime.timedelta:
        return datetime.timedelta(hours=10)

    def tzname(self, dt: Optional[datetime.datetime] = None) -> str:
        return "TST"

    def dst(self, dt: Optional[datetime.datetime] = None) -> datetime.timedelta:
        return datetime.timedelta(0)


tst = TSTTzinfo()
